==> vtigercrm-5.3.0p0.tgz: modules/Leads/language/es_mx.lang.php <==
<?php
/***********************************************************
*  License      : 
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Leads
*  Language     : Español
*  Version      : 504
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2008-09-20
*  Author       : Joe Bordes JPL TSolucio, S.L.
*  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/


$mod_strings = Array(
'LBL_MODULE_NAME'=>'Prospectos',
'LBL_DIRECT_REPORTS_FORM_NAME'=>'Informes Directos',
'LBL_MODULE_TITLE'=>'Prospectos: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Prospecto',
'LBL_LIST_FORM_TITLE'=>'Lista de Prospectos',
'LBL_NEW_FORM_TITLE'=>'Nuevo Prospecto',
'LBL_LEAD_OPP_FORM_TITLE'=>'Contacto-Oportunidad:',
'LBL_LEAD'=>'Prospecto:',
'LBL_ADDRESS_INFORMATION'=>'Información de la Dirección',
'LBL_CUSTOM_INFORMATION'=>'Información Específica',

'LBL_LIST_NAME'=>'Nombre',
'LBL_LIST_LAST_NAME'=>'Apellido',
'LBL_LIST_COMPANY'=>'Cuenta',
'LBL_LIST_WEBSITE'=>'Página Web',
'LBL_LIST_LEAD_NAME'=>'Prospectos ',
'LBL_LIST_EMAIL'=>'Email',
'LBL_LIST_PHONE'=>'Teléfono',
'LBL_LIST_LEAD_ROLE'=>'Rol',

'LBL_NAME'=>'Nombre:',
'LBL_LEAD_NAME'=>' Prospecto:',
'LBL_LEAD_INFORMATION'=>'Infomación del Prospecto',
'LBL_FIRST_NAME'=>'Nombre:',
'LBL_PHONE'=>'Teléfono:',
'LBL_COMPANY'=>'Cuenta:',
'LBL_DESIGNATION'=>'Designación:',
'LBL_PHONE'=>'Teléfono:',
'LBL_LAST_NAME'=>'Apellido:',
'LBL_MOBILE'=>'Tel. Móvil:',
'LBL_EMAIL'=>'Email:',
'LBL_LEAD_SOURCE'=>'Origen:',
'LBL_LEAD_STATUS'=>'Estado:',
'LBL_WEBSITE'=>'Página Web:',
'LBL_FAX'=>'Fax:',
'LBL_INDUSTRY'=>'Actividad:',
'LBL_ANNUAL_REVENUE'=>'Facturación Anual:',
'LBL_RATING'=>'Valoración:',
'LBL_LICENSE_KEY'=>'Clave de la Licencia:',
'LBL_NO_OF_EMPLOYEES'=>'Numero de Empleados:',
'LBL_YAHOO_ID'=>'Mensajería instantanea:',

'LBL_ADDRESS_STREET'=>'Dirección:',
'LBL_ADDRESS_POSTAL_CODE'=>'Código Postal:',
'LBL_ADDRESS_CITY'=>'Deleg./Mpio.:',
'LBL_ADDRESS_COUNTRY'=>'País:',
'LBL_ADDRESS_STATE'=>'Estado:',
'LBL_ADDRESS'=>'Dirección:',
'LBL_DESCRIPTION_INFORMATION'=>'Información Adicional',
'LBL_DESCRIPTION'=>'Descripción:',

'LBL_CONVERT_LEAD'=>'Convertir Prospecto:',
'LBL_CONVERT_LEAD_INFORMATION'=>'Convertir Información del Prospecto',
'LBL_ACCOUNT_NAME'=>'Nombre de la Cuenta',
'LBL_POTENTIAL_NAME'=>'Oportunidad',
'LBL_POTENTIAL_CLOSE_DATE'=>'Fecha de cierre de la Oportunidad',
'LBL_POTENTIAL_AMOUNT'=>'Importe de la Oportunidad',
'LBL_POTENTIAL_SALES_STAGE'=>'Estado de la Oportunidad',


'NTC_DELETE_CONFIRMATION'=>'¿Está seguro que desea eliminar este registro?',
'NTC_REMOVE_CONFIRMATION'=>'¿Está seguro que desea eliminar el contacto de este Prospecto?',
'NTC_REMOVE_DIRECT_REPORT_CONFIRMATION'=>'¿Está usted seguro usted desea quitar este registro como un informe directo?',
'NTC_REMOVE_OPP_CONFIRMATION'=>'¿Est&aacute seguro usted desea eliminar este contacto de esta oportunidad?',
'ERR_DELETE_RECORD'=>'Debe especificar un registro para poder eliminar el contacto.',
'NTC_COPY_PRIMARY_ADDRESS'=>'Copiar principal a alternativa',
'NTC_COPY_ALTERNATE_ADDRESS'=>'Copiar alternativa a principal',

// Added vtiger_fields in fetchfile.php, import.php -- crm4-Beta
'LBL_COLON'=>' : ',
'LBL_IMPORT_LEADS'=>'Importar Prospecto',
'LBL_LEADS_FILE_LIST'=>'Lista de archivos Prospecto',
'LBL_INSTRUCTIONS'=>'Instruciones',
'LBL_KINDLY_PROVIDE_AN_XLS_FILE'=>'Indique un archivo .xls como entrada',
'LBL_PROVIDE_ATLEAST_ONE_FILE'=>'Por favor, indique al menos un archivo como entrada',

'LBL_NONE'=>'Ninguno',
'LBL_ASSIGNED_TO'=>'Asignado a:',
'LBL_SELECT_LEAD'=>'Seleccionar Prospectos',
'LBL_GENERAL_INFORMATION'=>'Información General',
'LBL_DO_NOT_CREATE_NEW_POTENTIAL'=>'No crear una nueva oportunidad tras la conversión',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nueva Oportunidad',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TASK'=>'Nueva Tarea',
'LBL_TASK_TITLE'=>'Tareas',
'LBL_NEW_CALL'=>'Nueva Llamada',
'LBL_CALL_TITLE'=>'Llamada',
'LBL_NEW_MEETING'=>'Nueva Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',
'LBL_NEW_EMAIL'=>'Nuevo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_NOTE'=>'Nuevo Documento',
'LBL_NOTE_TITLE'=>'Documentos',
'LBL_NEW_ATTACHMENT'=>'Nuevo Adjunto',
'LBL_ATTACHMENT_TITLE'=>'Adjuntos',


//Added vtiger_fields after RC1 - Release 
'LBL_ALL'=>'Todo',
'LBL_CONTACTED'=>'Contactado',
'LBL_LOST'=>'Perdido',
'LBL_HOT'=>'Caliente',
'LBL_COLD'=>'Frio',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Herramientas de Prospecto',

'LBL_SELECT_TEMPLATE_TO_MAIL_MERGE'=>'Seleccione una plantilla para enviar el Mailing:',

//Added for 4GA
'Salutation'=>'Saludo',
'First Name'=>'Nombre',
'Phone'=>'Teléfono',
'Last Name'=>'Apellidos',
'Mobile'=>'Tel .Móvil',
'Company'=>'Empresa',
'Fax'=>'Fax',
'Email'=>'Email',
'Lead Source'=>'Origen del Prospecto',
'Website'=>'Página Web',
'Annual Revenue'=>'Facturación Anual',
'Lead Status'=>'Estado del Prospecto',
'Industry'=>'Actividad',
'Rating'=>'Valoración',
'No Of Employees'=>'Número de Empleados',
'Assigned To'=>'Asignado a',
'Yahoo Id'=>'Mensajería instantanea',
'Created Time'=>'Fecha de Creación',
'Modified Time'=>'Última Modificación',
'Street'=>'Dirección',
'Postal Code'=>'Código Postal',
'City'=>'Deleg./Mpio.',
'Country'=>'País',
'State'=>'Estado',
'Description'=>'Descripción',
'Po Box'=>'Colonia',
'Campaign Source'=>'Campaña Origen',
//Added for CustomView 4.2 Release
'Name'=>'Nombre',
'LBL_NEW_LEADS'=>'Mis Prospectos',

//Added for Existing Picklist Entries

'--None--'=>'-----',
'Mr.'=>'Sr.',
'Ms.'=>'Sra.',
'Mrs.'=>'Srta.',
'Dr.'=>'Dr.',
'Prof.'=>'Prof.',

'Acquired'=>'Adquirido',
'Active'=>'Activo',
'Market Failed'=>'Mercado Inmaduro',
'Project Cancelled'=>'Cancelado',
'Shutdown'=>'Detenido',

'Apparel'=>'Ropa/Lenceria',
'Banking'=>'Banca',
'Biotechnology'=>'Biotecnología',
'Chemicals'=>'Químicas',
'Communications'=>'Comunicaciones',
'Construction'=>'Construcción',
'Consulting'=>'Consultoría',
'Education'=>'Educación',
'Electronics'=>'Electronica',
'Energy'=>'Energía',
'Engineering'=>'Ingeniería',
'Entertainment'=>'Entretenimiento',
'Environmental'=>'Medio Ambiente',
'Finance'=>'Finanzas',
'Food & Beverage'=>'Restauración',
'Government'=>'Gobierno',
'Healthcare'=>'Salud',
'Hospitality'=>'Hospital',
'Insurance'=>'Seguros',
'Machinery'=>'Maquinaria',
'Manufacturing'=>'Fabricación',
'Media'=>'Medios',
'Not For Profit'=>'ONG',
'Recreation'=>'Ocio',
'Retail'=>'Venta al por menor',
'Shipping'=>'Logística',
'Technology'=>'Tecnología',
'Telecommunications'=>'Telecomunicaciones',
'Transportation'=>'Transportes',
'Utilities'=>'Utilidades',
'Other'=>'Otros',

'Cold Call'=>'Llamada',
'Existing Customer'=>'Cliente',
'Self Generated'=>'Autogenerada',
'Employee'=>'Trabajador',
'Partner'=>'Socio',
'Public Relations'=>'Relaciones Públicas',
'Direct Mail'=>'Mailing',
'Conference'=>'Conferencia',
'Trade Show'=>'Feria',
'Web Site'=>'Web Site',
'Word of mouth'=>'Boca a Boca',

'Attempted to Contact'=>'Intentado Contactar',
'Cold'=>'Frio',
'Contact in Future'=>'Contactar más adelante',
'Contacted'=>'Contactado',
'Hot'=>'Caliente',
'Junk Lead'=>'Prospecto Basura',
'Lost Lead'=>'Prospecto Fallido',
'Not Contacted'=>'No Contactado',
'Pre Qualified'=>'Pre Calificado',
'Qualified'=>'Calificado',
'Warm'=>'Tibio',

// Added/Updated for vtiger CRM 5.0.4

'Designation'=>'Designación',
     
// Added after 5.0.4 GA

//Module Sequence Numbering
'Lead No'=>'Núm. Prospecto',
// END

'LBL_TRANSFER_RELATED_RECORDS_TO' => 'Transferir elementos relacionados a',
);

?>

==> vtigercrm-5.4.0.tgz: modules/Leads/language/es_mx.lang.php <==
<?php
/***********************************************************
*  License      : 
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Leads
*  Language     : Español
*  Version      : 5.4.0
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2012-02-28
*  Author       : Joe Bordes JPL TSolucio, S.L.
*  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/


$mod_strings = Array(
'LBL_MODULE_NAME'=>'Prospectos',
'LBL_DIRECT_REPORTS_FORM_NAME'=>'Informes Directos',
'LBL_MODULE_TITLE'=>'Prospectos: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Prospecto',
'LBL_LIST_FORM_TITLE'=>'Lista de Prospectos',
'LBL_NEW_FORM_TITLE'=>'Nuevo Prospecto',
'LBL_LEAD_OPP_FORM_TITLE'=>'Contacto-Oportunidad:',
'LBL_LEAD'=>'Prospecto:',
'LBL_ADDRESS_INFORMATION'=>'Información de la Dirección',
'LBL_CUSTOM_INFORMATION'=>'Información Específica',

'LBL_LIST_NAME'=>'Nombre',
'LBL_LIST_LAST_NAME'=>'Apellido',
'LBL_LIST_COMPANY'=>'Cuenta',
'LBL_LIST_WEBSITE'=>'Página Web',
'LBL_LIST_LEAD_NAME'=>'Prospectos ',
'LBL_LIST_EMAIL'=>'Email',
'LBL_LIST_PHONE'=>'Teléfono',
'LBL_LIST_LEAD_ROLE'=>'Rol',

'LBL_NAME'=>'Nombre:',
'LBL_LEAD_NAME'=>' Prospecto:',
'LBL_LEAD_INFORMATION'=>'Infomación del Prospecto',
'LBL_FIRST_NAME'=>'Nombre:',
'LBL_PHONE'=>'Teléfono:',
'LBL_COMPANY'=>'Cuenta:',
'LBL_DESIGNATION'=>'Designación:',
'LBL_PHONE'=>'Teléfono:',
'LBL_LAST_NAME'=>'Apellido:',
'LBL_MOBILE'=>'Tel. Móvil:',
'LBL_EMAIL'=>'Email:',
'LBL_LEAD_SOURCE'=>'Origen:',
'LBL_LEAD_STATUS'=>'Estado:',
'LBL_WEBSITE'=>'Página Web:',
'LBL_FAX'=>'Fax:',
'LBL_INDUSTRY'=>'Actividad:',
'LBL_ANNUAL_REVENUE'=>'Facturación Anual:',
'LBL_RATING'=>'Valoración:',
'LBL_LICENSE_KEY'=>'Clave de la Licencia:',
'LBL_NO_OF_EMPLOYEES'=>'Numero de Empleados:',
'LBL_YAHOO_ID'=>'Mensajería instantanea:',

'LBL_ADDRESS_STREET'=>'Dirección:',
'LBL_ADDRESS_POSTAL_CODE'=>'Código Postal:',
'LBL_ADDRESS_CITY'=>'Deleg./Mpio.:',
'LBL_ADDRESS_COUNTRY'=>'País:',
'LBL_ADDRESS_STATE'=>'Estado:',
'LBL_ADDRESS'=>'Dirección:',
'LBL_DESCRIPTION_INFORMATION'=>'Información Adicional',
'LBL_DESCRIPTION'=>'Descripción:',

'LBL_CONVERT_LEAD'=>'Convertir Prospecto:',
'LBL_CONVERT_LEAD_INFORMATION'=>'Convertir Información del Prospecto',
'LBL_ACCOUNT_NAME'=>'Nombre de la Cuenta',
'LBL_POTENTIAL_NAME'=>'Oportunidad',
'LBL_POTENTIAL_CLOSE_DATE'=>'Fecha de cierre de la Oportunidad',
'LBL_POTENTIAL_AMOUNT'=>'Importe de la Oportunidad',
'LBL_POTENTIAL_SALES_STAGE'=>'Estado de la Oportunidad',


'NTC_DELETE_CONFIRMATION'=>'¿Está seguro que desea eliminar este registro?',
'NTC_REMOVE_CONFIRMATION'=>'¿Está seguro que desea eliminar el contacto de este Prospecto?',
'NTC_REMOVE_DIRECT_REPORT_CONFIRMATION'=>'¿Está usted seguro usted desea quitar este registro como un informe directo?',
'NTC_REMOVE_OPP_CONFIRMATION'=>'¿Est&aacute seguro usted desea eliminar este contacto de esta oportunidad?',
'ERR_DELETE_RECORD'=>'Debe especificar un registro para poder eliminar el contacto.',
'NTC_COPY_PRIMARY_ADDRESS'=>'Copiar principal a alternativa',
'NTC_COPY_ALTERNATE_ADDRESS'=>'Copiar alternativa a principal',

// Added vtiger_fields in fetchfile.php, import.php -- crm4-Beta
'LBL_COLON'=>' : ',
'LBL_IMPORT_LEADS'=>'Importar Prospecto',
'LBL_LEADS_FILE_LIST'=>'Lista de archivos Prospecto',
'LBL_INSTRUCTIONS'=>'Instruciones',
'LBL_KINDLY_PROVIDE_AN_XLS_FILE'=>'Indique un archivo .xls como entrada',
'LBL_PROVIDE_ATLEAST_ONE_FILE'=>'Por favor, indique al menos un archivo como entrada',

'LBL_NONE'=>'Ninguno',
'LBL_ASSIGNED_TO'=>'Asignado a:',
'LBL_SELECT_LEAD'=>'Seleccionar Prospectos',
'LBL_GENERAL_INFORMATION'=>'Información General',
'LBL_DO_NOT_CREATE_NEW_POTENTIAL'=>'No crear una nueva oportunidad tras la conversión',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nueva Oportunidad',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TASK'=>'Nueva Tarea',
'LBL_TASK_TITLE'=>'Tareas',
'LBL_NEW_CALL'=>'Nueva Llamada',
'LBL_CALL_TITLE'=>'Llamada',
'LBL_NEW_MEETING'=>'Nueva Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',
'LBL_NEW_EMAIL'=>'Nuevo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_NOTE'=>'Nuevo Documento',
'LBL_NOTE_TITLE'=>'Documentos',
'LBL_NEW_ATTACHMENT'=>'Nuevo Adjunto',
'LBL_ATTACHMENT_TITLE'=>'Adjuntos',


//Added vtiger_fields after RC1 - Release 
'LBL_ALL'=>'Todo',
'LBL_CONTACTED'=>'Contactado',
'LBL_LOST'=>'Perdido',
'LBL_HOT'=>'Caliente',
'LBL_COLD'=>'Frio',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Herramientas de Prospecto',

'LBL_SELECT_TEMPLATE_TO_MAIL_MERGE'=>'Seleccione una plantilla para enviar el Mailing:',

//Added for 4GA
'Salutation'=>'Saludo',
'First Name'=>'Nombre',
'Phone'=>'Teléfono',
'Last Name'=>'Apellidos',
'Mobile'=>'Tel .Móvil',
'Company'=>'Empresa',
'Fax'=>'Fax',
'Email'=>'Email',
'Lead Source'=>'Origen del Prospecto',
'Website'=>'Página Web',
'Annual Revenue'=>'Facturación Anual',
'Lead Status'=>'Estado del Prospecto',
'Industry'=>'Actividad',
'Rating'=>'Valoración',
'No Of Employees'=>'Número de Empleados',
'Assigned To'=>'Asignado a',
'Yahoo Id'=>'Mensajería instantanea',
'Created Time'=>'Fecha de Creación',
'Modified Time'=>'Última Modificación',
'Street'=>'Dirección',
'Postal Code'=>'Código Postal',
'City'=>'Deleg./Mpio.',
'Country'=>'País',
'State'=>'Estado',
'Description'=>'Descripción',
'Po Box'=>'Colonia',
'Campaign Source'=>'Campaña Origen',
//Added for CustomView 4.2 Release
'Name'=>'Nombre',
'LBL_NEW_LEADS'=>'Mis Prospectos',

//Added for Existing Picklist Entries

'--None--'=>'-----',
'Mr.'=>'Sr.',
'Ms.'=>'Sra.',
'Mrs.'=>'Srta.',
'Dr.'=>'Dr.',
'Prof.'=>'Prof.',

'Acquired'=>'Adquirido',
'Active'=>'Activo',
'Market Failed'=>'Mercado Inmaduro',
'Project Cancelled'=>'Cancelado',
'Shutdown'=>'Detenido',

'Apparel'=>'Ropa/Lenceria',
'Banking'=>'Banca',
'Biotechnology'=>'Biotecnología',
'Chemicals'=>'Químicas',
'Communications'=>'Comunicaciones',
'Construction'=>'Construcción',
'Consulting'=>'Consultoría',
'Education'=>'Educación',
'Electronics'=>'Electronica',
'Energy'=>'Energía',
'Engineering'=>'Ingeniería',
'Entertainment'=>'Entretenimiento',
'Environmental'=>'Medio Ambiente',
'Finance'=>'Finanzas',
'Food & Beverage'=>'Restauración',
'Government'=>'Gobierno',
'Healthcare'=>'Salud',
'Hospitality'=>'Hospital',
'Insurance'=>'Seguros',
'Machinery'=>'Maquinaria',
'Manufacturing'=>'Fabricación',
'Media'=>'Medios',
'Not For Profit'=>'ONG',
'Recreation'=>'Ocio',
'Retail'=>'Venta al por menor',
'Shipping'=>'Logística',
'Technology'=>'Tecnología',
'Telecommunications'=>'Telecomunicaciones',
'Transportation'=>'Transportes',
'Utilities'=>'Utilidades',
'Other'=>'Otros',

'Cold Call'=>'Llamada',
'Existing Customer'=>'Cliente',
'Self Generated'=>'Autogenerada',
'Employee'=>'Trabajador',
'Partner'=>'Socio',
'Public Relations'=>'Relaciones Públicas',
'Direct Mail'=>'Mailing',
'Conference'=>'Conferencia',
'Trade Show'=>'Feria',
'Web Site'=>'Web Site',
'Word of mouth'=>'Boca a Boca',

'Attempted to Contact'=>'Intentado Contactar',
'Cold'=>'Frio',
'Contact in Future'=>'Contactar más adelante',
'Contacted'=>'Contactado',
'Hot'=>'Caliente',
'Junk Lead'=>'Prospecto Basura',
'Lost Lead'=>'Prospecto Fallido',
'Not Contacted'=>'No Contactado',
'Pre Qualified'=>'Pre Calificado',
'Qualified'=>'Calificado',
'Warm'=>'Tibio',

// Added/Updated for vtiger CRM 5.0.4

'Designation'=>'Designación',
     
// Added after 5.0.4 GA

//Module Sequence Numbering
'Lead No'=>'Núm. Prospecto',
// END

'LBL_TRANSFER_RELATED_RECORDS_TO' => 'Transferir elementos relacionados a',

'LBL_FOLLOWING_ARE_POSSIBLE_REASONS' => 'A continuación se detallan algunas de las posibles causas',
'LBL_LEADS_FIELD_MAPPING_INCOMPLETE' => 'No se han vinculado todos los campos obligatorios',
'LBL_MANDATORY_FIELDS_ARE_EMPTY' => 'Algún campo obligatorio está vacío',
'LBL_LEADS_FIELD_MAPPING' => 'Vinculación de Campos Personalizados',

'LBL_FIELD_SETTINGS' => 'Configuración Campos',
'Leads ID' => 'Id Prospecto',

);

?>
